==> mfc-api-model-0.1.1-sources.jar: com/valor/mfc/vms/api/model/user/SessionInfoDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

public class SessionInfoDo extends AbstractPrintable {

    private String subAccountName;
    private String did;
    private Long duration;
    private String clientSession;
    private Long accountId;
    private Integer accountType;

    public SessionInfoDo(String subAccountName, String did, Long duration, String clientSession, Long accountId, Integer accountType) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
        this.clientSession = clientSession;
        this.accountId = accountId;
        this.accountType = accountType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public SessionInfoDo() {
    }

    public SessionInfoDo(String subAccountName, String did, Long duration, String clientSession) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
        this.clientSession = clientSession;
    }

    public String getClientSession() {
        return clientSession;
    }

    public void setClientSession(String clientSession) {
        this.clientSession = clientSession;
    }

    public SessionInfoDo(String subAccountName, String did, Long duration) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
    }

    public String getSubAccountName() {
        return subAccountName;
    }

    public void setSubAccountName(String subAccountName) {
        this.subAccountName = subAccountName;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getDuration() {
        return duration;
    }

    public void setDuration(Long duration) {
        this.duration = duration;
    }
}

==> mfc-api-model-0.1.6-sources.jar: com/valor/mfc/vms/api/model/user/SessionInfoDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

public class SessionInfoDo extends AbstractPrintable {

    private String subAccountName;
    private String did;
    private Long duration;
    private String clientSession;
    private Long accountId;
    private Integer accountType;
    private String brand;
    private Long iconId;
    private int clientType;

    public SessionInfoDo(String subAccountName, String did, Long duration, String clientSession, Long accountId, Integer accountType) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
        this.clientSession = clientSession;
        this.accountId = accountId;
        this.accountType = accountType;
    }

    public SessionInfoDo(String subAccountName, String did, Long duration, String clientSession, Long accountId, Integer accountType, String brand, Long iconId) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
        this.clientSession = clientSession;
        this.accountId = accountId;
        this.accountType = accountType;
        this.brand = brand;
        this.iconId = iconId;
    }

    public SessionInfoDo(String subAccountName, String did, Long duration, String clientSession, Long accountId, Integer accountType, String brand, Long iconId, int clientType) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
        this.clientSession = clientSession;
        this.accountId = accountId;
        this.accountType = accountType;
        this.brand = brand;
        this.iconId = iconId;
        this.clientType = clientType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public SessionInfoDo() {
    }

    public SessionInfoDo(String subAccountName, String did, Long duration, String clientSession) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
        this.clientSession = clientSession;
    }

    public String getClientSession() {
        return clientSession;
    }

    public void setClientSession(String clientSession) {
        this.clientSession = clientSession;
    }

    public SessionInfoDo(String subAccountName, String did, Long duration) {
        this.subAccountName = subAccountName;
        this.did = did;
        this.duration = duration;
    }

    public String getSubAccountName() {
        return subAccountName;
    }

    public void setSubAccountName(String subAccountName) {
        this.subAccountName = subAccountName;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getDuration() {
        return duration;
    }

    public void setDuration(Long duration) {
        this.duration = duration;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public Long getIconId() { return iconId; }

    public void setIconId(Long iconId) { this.iconId = iconId; }

    public int getClientType() { return clientType; }

    public void setClientType(int clientType) { this.clientType = clientType; }
}
